Class: Aws::AmplifyUIBuilder::Types::CodegenDependency

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-amplifyuibuilder/types.rb

Overview

Dependency package that may be required for the project code to run.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#is_sem_ver ⇒ Boolean

Determines if the dependency package is using Semantic versioning. If set to true, it indicates that the dependency package uses Semantic versioning.



138
139
140
141
142
143
144
145
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 138

class CodegenDependency < Struct.new(
  :name,
  :supported_version,
  :is_sem_ver,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

Name of the dependency package.



138
139
140
141
142
143
144
145
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 138

class CodegenDependency < Struct.new(
  :name,
  :supported_version,
  :is_sem_ver,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#reason ⇒ String

Indicates the reason to include the dependency package in your project code.



138
139
140
141
142
143
144
145
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 138

class CodegenDependency < Struct.new(
  :name,
  :supported_version,
  :is_sem_ver,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#supported_version ⇒ String

Indicates the version of the supported dependency package.



138
139
140
141
142
143
144
145
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 138

class CodegenDependency < Struct.new(
  :name,
  :supported_version,
  :is_sem_ver,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end