Class: Aws::AmplifyUIBuilder::Types::Component

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-amplifyuibuilder/types.rb

Overview

Contains the configuration settings for a user interface (UI) element for an Amplify app. A component is configured as a primary, stand-alone UI element. Use ComponentChild to configure an instance of a Component. A ComponentChild instance inherits the configuration of the main Component.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_id ⇒ String

The unique ID of the Amplify app associated with the component.



591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 591

class Component < Struct.new(
  :app_id,
  :environment_name,
  :source_id,
  :id,
  :name,
  :component_type,
  :properties,
  :children,
  :variants,
  :overrides,
  :binding_properties,
  :collection_properties,
  :created_at,
  :modified_at,
  :tags,
  :events,
  :schema_version)
  SENSITIVE = []
  include Aws::Structure
end

#binding_properties ⇒ Hash<String,Types::ComponentBindingPropertiesValue>

The information to connect a component's properties to data at runtime. You can't specify tags as a valid property for bindingProperties.



591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 591

class Component < Struct.new(
  :app_id,
  :environment_name,
  :source_id,
  :id,
  :name,
  :component_type,
  :properties,
  :children,
  :variants,
  :overrides,
  :binding_properties,
  :collection_properties,
  :created_at,
  :modified_at,
  :tags,
  :events,
  :schema_version)
  SENSITIVE = []
  include Aws::Structure
end

#children ⇒ Array<Types::ComponentChild>

A list of the component's ComponentChild instances.



591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 591

class Component < Struct.new(
  :app_id,
  :environment_name,
  :source_id,
  :id,
  :name,
  :component_type,
  :properties,
  :children,
  :variants,
  :overrides,
  :binding_properties,
  :collection_properties,
  :created_at,
  :modified_at,
  :tags,
  :events,
  :schema_version)
  SENSITIVE = []
  include Aws::Structure
end

#collection_properties ⇒ Hash<String,Types::ComponentDataConfiguration>

The data binding configuration for the component's properties. Use this for a collection component. You can't specify tags as a valid property for collectionProperties.



591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 591

class Component < Struct.new(
  :app_id,
  :environment_name,
  :source_id,
  :id,
  :name,
  :component_type,
  :properties,
  :children,
  :variants,
  :overrides,
  :binding_properties,
  :collection_properties,
  :created_at,
  :modified_at,
  :tags,
  :events,
  :schema_version)
  SENSITIVE = []
  include Aws::Structure
end

#component_type ⇒ String

The type of the component. This can be an Amplify custom UI component or another custom component.



591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 591

class Component < Struct.new(
  :app_id,
  :environment_name,
  :source_id,
  :id,
  :name,
  :component_type,
  :properties,
  :children,
  :variants,
  :overrides,
  :binding_properties,
  :collection_properties,
  :created_at,
  :modified_at,
  :tags,
  :events,
  :schema_version)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

The time that the component was created.



591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 591

class Component < Struct.new(
  :app_id,
  :environment_name,
  :source_id,
  :id,
  :name,
  :component_type,
  :properties,
  :children,
  :variants,
  :overrides,
  :binding_properties,
  :collection_properties,
  :created_at,
  :modified_at,
  :tags,
  :events,
  :schema_version)
  SENSITIVE = []
  include Aws::Structure
end

#environment_name ⇒ String

The name of the backend environment that is a part of the Amplify app.



591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 591

class Component < Struct.new(
  :app_id,
  :environment_name,
  :source_id,
  :id,
  :name,
  :component_type,
  :properties,
  :children,
  :variants,
  :overrides,
  :binding_properties,
  :collection_properties,
  :created_at,
  :modified_at,
  :tags,
  :events,
  :schema_version)
  SENSITIVE = []
  include Aws::Structure
end

#events ⇒ Hash<String,Types::ComponentEvent>

Describes the events that can be raised on the component. Use for the workflow feature in Amplify Studio that allows you to bind events and actions to components.



591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 591

class Component < Struct.new(
  :app_id,
  :environment_name,
  :source_id,
  :id,
  :name,
  :component_type,
  :properties,
  :children,
  :variants,
  :overrides,
  :binding_properties,
  :collection_properties,
  :created_at,
  :modified_at,
  :tags,
  :events,
  :schema_version)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The unique ID of the component.



591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 591

class Component < Struct.new(
  :app_id,
  :environment_name,
  :source_id,
  :id,
  :name,
  :component_type,
  :properties,
  :children,
  :variants,
  :overrides,
  :binding_properties,
  :collection_properties,
  :created_at,
  :modified_at,
  :tags,
  :events,
  :schema_version)
  SENSITIVE = []
  include Aws::Structure
end

#modified_at ⇒ Time

The time that the component was modified.



591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 591

class Component < Struct.new(
  :app_id,
  :environment_name,
  :source_id,
  :id,
  :name,
  :component_type,
  :properties,
  :children,
  :variants,
  :overrides,
  :binding_properties,
  :collection_properties,
  :created_at,
  :modified_at,
  :tags,
  :events,
  :schema_version)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the component.



591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 591

class Component < Struct.new(
  :app_id,
  :environment_name,
  :source_id,
  :id,
  :name,
  :component_type,
  :properties,
  :children,
  :variants,
  :overrides,
  :binding_properties,
  :collection_properties,
  :created_at,
  :modified_at,
  :tags,
  :events,
  :schema_version)
  SENSITIVE = []
  include Aws::Structure
end

#overrides ⇒ Hash<String,Hash<String,String>>

Describes the component's properties that can be overriden in a customized instance of the component. You can't specify tags as a valid property for overrides.



591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 591

class Component < Struct.new(
  :app_id,
  :environment_name,
  :source_id,
  :id,
  :name,
  :component_type,
  :properties,
  :children,
  :variants,
  :overrides,
  :binding_properties,
  :collection_properties,
  :created_at,
  :modified_at,
  :tags,
  :events,
  :schema_version)
  SENSITIVE = []
  include Aws::Structure
end

#properties ⇒ Hash<String,Types::ComponentProperty>

Describes the component's properties. You can't specify tags as a valid property for properties.



591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 591

class Component < Struct.new(
  :app_id,
  :environment_name,
  :source_id,
  :id,
  :name,
  :component_type,
  :properties,
  :children,
  :variants,
  :overrides,
  :binding_properties,
  :collection_properties,
  :created_at,
  :modified_at,
  :tags,
  :events,
  :schema_version)
  SENSITIVE = []
  include Aws::Structure
end

#schema_version ⇒ String

The schema version of the component when it was imported.



591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 591

class Component < Struct.new(
  :app_id,
  :environment_name,
  :source_id,
  :id,
  :name,
  :component_type,
  :properties,
  :children,
  :variants,
  :overrides,
  :binding_properties,
  :collection_properties,
  :created_at,
  :modified_at,
  :tags,
  :events,
  :schema_version)
  SENSITIVE = []
  include Aws::Structure
end

#source_id ⇒ String

The unique ID of the component in its original source system, such as Figma.



591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 591

class Component < Struct.new(
  :app_id,
  :environment_name,
  :source_id,
  :id,
  :name,
  :component_type,
  :properties,
  :children,
  :variants,
  :overrides,
  :binding_properties,
  :collection_properties,
  :created_at,
  :modified_at,
  :tags,
  :events,
  :schema_version)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

One or more key-value pairs to use when tagging the component.



591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 591

class Component < Struct.new(
  :app_id,
  :environment_name,
  :source_id,
  :id,
  :name,
  :component_type,
  :properties,
  :children,
  :variants,
  :overrides,
  :binding_properties,
  :collection_properties,
  :created_at,
  :modified_at,
  :tags,
  :events,
  :schema_version)
  SENSITIVE = []
  include Aws::Structure
end

#variants ⇒ Array<Types::ComponentVariant>

A list of the component's variants. A variant is a unique style configuration of a main component.



591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 591

class Component < Struct.new(
  :app_id,
  :environment_name,
  :source_id,
  :id,
  :name,
  :component_type,
  :properties,
  :children,
  :variants,
  :overrides,
  :binding_properties,
  :collection_properties,
  :created_at,
  :modified_at,
  :tags,
  :events,
  :schema_version)
  SENSITIVE = []
  include Aws::Structure
end