Class: Aws::AmplifyUIBuilder::Types::ComponentBindingPropertiesValueProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-amplifyuibuilder/types.rb

Overview

Represents the data binding configuration for a specific property using data stored in Amazon Web Services. For Amazon Web Services connected properties, you can bind a property to data stored in an Amazon S3 bucket, an Amplify DataStore model or an authenticated user attribute.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucket ⇒ String

An Amazon S3 bucket.

Returns:

  • (String)


680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 680

class ComponentBindingPropertiesValueProperties < Struct.new(
  :model,
  :field,
  :predicates,
  :user_attribute,
  :bucket,
  :key,
  :default_value,
  :slot_name)
  SENSITIVE = []
  include Aws::Structure
end

#default_value ⇒ String

The default value to assign to the property.

Returns:

  • (String)


680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 680

class ComponentBindingPropertiesValueProperties < Struct.new(
  :model,
  :field,
  :predicates,
  :user_attribute,
  :bucket,
  :key,
  :default_value,
  :slot_name)
  SENSITIVE = []
  include Aws::Structure
end

#field ⇒ String

The field to bind the data to.

Returns:

  • (String)


680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 680

class ComponentBindingPropertiesValueProperties < Struct.new(
  :model,
  :field,
  :predicates,
  :user_attribute,
  :bucket,
  :key,
  :default_value,
  :slot_name)
  SENSITIVE = []
  include Aws::Structure
end

#key ⇒ String

The storage key for an Amazon S3 bucket.

Returns:

  • (String)


680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 680

class ComponentBindingPropertiesValueProperties < Struct.new(
  :model,
  :field,
  :predicates,
  :user_attribute,
  :bucket,
  :key,
  :default_value,
  :slot_name)
  SENSITIVE = []
  include Aws::Structure
end

#model ⇒ String

An Amplify DataStore model.

Returns:

  • (String)


680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 680

class ComponentBindingPropertiesValueProperties < Struct.new(
  :model,
  :field,
  :predicates,
  :user_attribute,
  :bucket,
  :key,
  :default_value,
  :slot_name)
  SENSITIVE = []
  include Aws::Structure
end

#predicates ⇒ Array<Types::Predicate>

A list of predicates for binding a component's properties to data.

Returns:



680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 680

class ComponentBindingPropertiesValueProperties < Struct.new(
  :model,
  :field,
  :predicates,
  :user_attribute,
  :bucket,
  :key,
  :default_value,
  :slot_name)
  SENSITIVE = []
  include Aws::Structure
end

#slot_name ⇒ String

The name of a component slot.

Returns:

  • (String)


680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 680

class ComponentBindingPropertiesValueProperties < Struct.new(
  :model,
  :field,
  :predicates,
  :user_attribute,
  :bucket,
  :key,
  :default_value,
  :slot_name)
  SENSITIVE = []
  include Aws::Structure
end

#user_attribute ⇒ String

An authenticated user attribute.

Returns:

  • (String)


680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 680

class ComponentBindingPropertiesValueProperties < Struct.new(
  :model,
  :field,
  :predicates,
  :user_attribute,
  :bucket,
  :key,
  :default_value,
  :slot_name)
  SENSITIVE = []
  include Aws::Structure
end