Class: Aws::AmplifyUIBuilder::Types::FieldInputConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-amplifyuibuilder/types.rb

Overview

Describes the configuration for the default input values to display for a field.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_checked ⇒ Boolean

Specifies whether a field has a default value.

Returns:

  • (Boolean)


1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 1684

class FieldInputConfig < Struct.new(
  :type,
  :required,
  :read_only,
  :placeholder,
  :default_value,
  :descriptive_text,
  :default_checked,
  :default_country_code,
  :value_mappings,
  :name,
  :min_value,
  :max_value,
  :step,
  :value,
  :is_array,
  :file_uploader_config)
  SENSITIVE = []
  include Aws::Structure
end

#default_country_code ⇒ String

The default country code for a phone number.

Returns:

  • (String)


1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 1684

class FieldInputConfig < Struct.new(
  :type,
  :required,
  :read_only,
  :placeholder,
  :default_value,
  :descriptive_text,
  :default_checked,
  :default_country_code,
  :value_mappings,
  :name,
  :min_value,
  :max_value,
  :step,
  :value,
  :is_array,
  :file_uploader_config)
  SENSITIVE = []
  include Aws::Structure
end

#default_value ⇒ String

The default value for the field.

Returns:

  • (String)


1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 1684

class FieldInputConfig < Struct.new(
  :type,
  :required,
  :read_only,
  :placeholder,
  :default_value,
  :descriptive_text,
  :default_checked,
  :default_country_code,
  :value_mappings,
  :name,
  :min_value,
  :max_value,
  :step,
  :value,
  :is_array,
  :file_uploader_config)
  SENSITIVE = []
  include Aws::Structure
end

#descriptive_text ⇒ String

The text to display to describe the field.

Returns:

  • (String)


1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 1684

class FieldInputConfig < Struct.new(
  :type,
  :required,
  :read_only,
  :placeholder,
  :default_value,
  :descriptive_text,
  :default_checked,
  :default_country_code,
  :value_mappings,
  :name,
  :min_value,
  :max_value,
  :step,
  :value,
  :is_array,
  :file_uploader_config)
  SENSITIVE = []
  include Aws::Structure
end

#file_uploader_config ⇒ Types::FileUploaderFieldConfig

The configuration for the file uploader field.



1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 1684

class FieldInputConfig < Struct.new(
  :type,
  :required,
  :read_only,
  :placeholder,
  :default_value,
  :descriptive_text,
  :default_checked,
  :default_country_code,
  :value_mappings,
  :name,
  :min_value,
  :max_value,
  :step,
  :value,
  :is_array,
  :file_uploader_config)
  SENSITIVE = []
  include Aws::Structure
end

#is_array ⇒ Boolean

Specifies whether to render the field as an array. This property is ignored if the dataSourceType for the form is a Data Store.

Returns:

  • (Boolean)


1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 1684

class FieldInputConfig < Struct.new(
  :type,
  :required,
  :read_only,
  :placeholder,
  :default_value,
  :descriptive_text,
  :default_checked,
  :default_country_code,
  :value_mappings,
  :name,
  :min_value,
  :max_value,
  :step,
  :value,
  :is_array,
  :file_uploader_config)
  SENSITIVE = []
  include Aws::Structure
end

#max_value ⇒ Float

The maximum value to display for the field.

Returns:

  • (Float)


1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 1684

class FieldInputConfig < Struct.new(
  :type,
  :required,
  :read_only,
  :placeholder,
  :default_value,
  :descriptive_text,
  :default_checked,
  :default_country_code,
  :value_mappings,
  :name,
  :min_value,
  :max_value,
  :step,
  :value,
  :is_array,
  :file_uploader_config)
  SENSITIVE = []
  include Aws::Structure
end

#min_value ⇒ Float

The minimum value to display for the field.

Returns:

  • (Float)


1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 1684

class FieldInputConfig < Struct.new(
  :type,
  :required,
  :read_only,
  :placeholder,
  :default_value,
  :descriptive_text,
  :default_checked,
  :default_country_code,
  :value_mappings,
  :name,
  :min_value,
  :max_value,
  :step,
  :value,
  :is_array,
  :file_uploader_config)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the field.

Returns:

  • (String)


1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 1684

class FieldInputConfig < Struct.new(
  :type,
  :required,
  :read_only,
  :placeholder,
  :default_value,
  :descriptive_text,
  :default_checked,
  :default_country_code,
  :value_mappings,
  :name,
  :min_value,
  :max_value,
  :step,
  :value,
  :is_array,
  :file_uploader_config)
  SENSITIVE = []
  include Aws::Structure
end

#placeholder ⇒ String

The text to display as a placeholder for the field.

Returns:

  • (String)


1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 1684

class FieldInputConfig < Struct.new(
  :type,
  :required,
  :read_only,
  :placeholder,
  :default_value,
  :descriptive_text,
  :default_checked,
  :default_country_code,
  :value_mappings,
  :name,
  :min_value,
  :max_value,
  :step,
  :value,
  :is_array,
  :file_uploader_config)
  SENSITIVE = []
  include Aws::Structure
end

#read_only ⇒ Boolean

Specifies a read only field.

Returns:

  • (Boolean)


1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 1684

class FieldInputConfig < Struct.new(
  :type,
  :required,
  :read_only,
  :placeholder,
  :default_value,
  :descriptive_text,
  :default_checked,
  :default_country_code,
  :value_mappings,
  :name,
  :min_value,
  :max_value,
  :step,
  :value,
  :is_array,
  :file_uploader_config)
  SENSITIVE = []
  include Aws::Structure
end

#required ⇒ Boolean

Specifies a field that requires input.

Returns:

  • (Boolean)


1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 1684

class FieldInputConfig < Struct.new(
  :type,
  :required,
  :read_only,
  :placeholder,
  :default_value,
  :descriptive_text,
  :default_checked,
  :default_country_code,
  :value_mappings,
  :name,
  :min_value,
  :max_value,
  :step,
  :value,
  :is_array,
  :file_uploader_config)
  SENSITIVE = []
  include Aws::Structure
end

#step ⇒ Float

The stepping increment for a numeric value in a field.

Returns:

  • (Float)


1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 1684

class FieldInputConfig < Struct.new(
  :type,
  :required,
  :read_only,
  :placeholder,
  :default_value,
  :descriptive_text,
  :default_checked,
  :default_country_code,
  :value_mappings,
  :name,
  :min_value,
  :max_value,
  :step,
  :value,
  :is_array,
  :file_uploader_config)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The input type for the field.

Returns:

  • (String)


1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 1684

class FieldInputConfig < Struct.new(
  :type,
  :required,
  :read_only,
  :placeholder,
  :default_value,
  :descriptive_text,
  :default_checked,
  :default_country_code,
  :value_mappings,
  :name,
  :min_value,
  :max_value,
  :step,
  :value,
  :is_array,
  :file_uploader_config)
  SENSITIVE = []
  include Aws::Structure
end

#value ⇒ String

The value for the field.

Returns:

  • (String)


1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 1684

class FieldInputConfig < Struct.new(
  :type,
  :required,
  :read_only,
  :placeholder,
  :default_value,
  :descriptive_text,
  :default_checked,
  :default_country_code,
  :value_mappings,
  :name,
  :min_value,
  :max_value,
  :step,
  :value,
  :is_array,
  :file_uploader_config)
  SENSITIVE = []
  include Aws::Structure
end

#value_mappings ⇒ Types::ValueMappings

The information to use to customize the input fields with data at runtime.



1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 1684

class FieldInputConfig < Struct.new(
  :type,
  :required,
  :read_only,
  :placeholder,
  :default_value,
  :descriptive_text,
  :default_checked,
  :default_country_code,
  :value_mappings,
  :name,
  :min_value,
  :max_value,
  :step,
  :value,
  :is_array,
  :file_uploader_config)
  SENSITIVE = []
  include Aws::Structure
end