Class: Aws::AmplifyUIBuilder::Types::StartCodegenJobData

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-amplifyuibuilder/types.rb

Overview

The code generation job resource configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_generate_forms ⇒ Boolean

Specifies whether to autogenerate forms in the code generation job.



2971
2972
2973
2974
2975
2976
2977
2978
2979
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 2971

class StartCodegenJobData < Struct.new(
  :render_config,
  :generic_data_schema,
  :auto_generate_forms,
  :features,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#features ⇒ Types::CodegenFeatureFlags

The feature flags for a code generation job.



2971
2972
2973
2974
2975
2976
2977
2978
2979
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 2971

class StartCodegenJobData < Struct.new(
  :render_config,
  :generic_data_schema,
  :auto_generate_forms,
  :features,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#generic_data_schema ⇒ Types::CodegenJobGenericDataSchema

The data schema to use for a code generation job.



2971
2972
2973
2974
2975
2976
2977
2978
2979
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 2971

class StartCodegenJobData < Struct.new(
  :render_config,
  :generic_data_schema,
  :auto_generate_forms,
  :features,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#render_config ⇒ Types::CodegenJobRenderConfig

The code generation configuration for the codegen job.



2971
2972
2973
2974
2975
2976
2977
2978
2979
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 2971

class StartCodegenJobData < Struct.new(
  :render_config,
  :generic_data_schema,
  :auto_generate_forms,
  :features,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

One or more key-value pairs to use when tagging the code generation job data.



2971
2972
2973
2974
2975
2976
2977
2978
2979
# File 'lib/aws-sdk-amplifyuibuilder/types.rb', line 2971

class StartCodegenJobData < Struct.new(
  :render_config,
  :generic_data_schema,
  :auto_generate_forms,
  :features,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end